@@ -15,7 +15,8 @@ from .risk_analysis_prompts import (
     PRODUCT_RISK_PROMPT,
     TEAM_RISK_PROMPT,
     UNSTRUCTURED_DATA_PROMPT,
-    PEER_BENCHMARK_PROMPT
+    PEER_BENCHMARK_PROMPT,
+    SOCIAL_COVERAGE_RISK_PROMPT
 )
 
 __all__ = [
@@ -29,5 +30,6 @@ __all__ = [
     "PRODUCT_RISK_PROMPT",
     "TEAM_RISK_PROMPT",
     "UNSTRUCTURED_DATA_PROMPT",
-    "PEER_BENCHMARK_PROMPT"
+    "PEER_BENCHMARK_PROMPT",
+    "SOCIAL_COVERAGE_RISK_PROMPT"
 ]
